; NAME:
;     cfile (Check File)
;
; PURPOSE:
;     To determine if a file exists. 
;
; CATEGORY:
;     Error Catching
;
; CALLING SEQUENCE:
;     result = cfile(filename,WIDGET_ID=widget_id,CANCEL=cancel)
;
; INPUTS:
;     filename - Name of a filename to check
;
; OUTUTS:
;     If the file is good, the filename is return.  If not, -1 is return.
;
; KEYWORD PARAMETERS:
;     WIDGET_ID - If given, an pop-up error message will appear over
;                 the widget. 
;     CANCEL    - Set on return if the file does not exist or if there 
;                 is a problem
;
; PROCEDURES CALLED:
;     Requires the Astronomy User's Library.
;
; PROCEDURE:
;     Uses the findfile routine.
;
; MODIFICATION HISTORY:
;     Written 2000-13-07 by M. Cushing, Institute for Astronomy, UH
;
function cfile,filename,WIDGET_ID=widget_id,CANCEL=cancel

cancel = 0

;  Check parameters

if n_params() lt 1 then begin
    
    print, 'Syntax -  result = cfile(filename,WIDGET_ID=widget_id,$'
    print, '                         CANCEL=cancel)'
    cancel = 1
    return, -1

endif
zparcheck, 'cfile', filename, 1, 7, 0, 'File name' 

widget = (n_elements(widget_id) ne 0) ? 1:0
mess = 'File '+filename+' does not exist.'

junk = findfile(filename, count=foundfile)
if foundfile eq 0 then begin
    
    if widget then ok = dialog_message(mess, /error,dialog_parent=widget_id)
    if not widget then print, mess
    cancel=1
    return, -1
        
endif 
return, filename


end        

