; NAME:
;     cpath (Check Path)
;
; PURPOSE:
;     1) To check if a path exists.  2) To add a trailing / if necessary.
;
; CATEGORY:
;     Error Catching
;
; CALLING SEQUENCE:
;     result = cpath(path,WIDGET_ID=widget_id,CANCEL=cancel)
;
; INPUTS:
;     path - String path name
;
; OUTUTS:
;     If the path is good, the path is return.  If not, -1 is return.
;
; KEYWORD PARAMETERS:
;     WIDGET_ID - If given, an pop-up error message will appear over
;                 the widget
;     CANCEL    - Set on return if the path does not exist or if there 
;                 there is a problem
;
; PROCEDURES CALLED:
;     Requires the Astronomy User's Library
;
; PROCEDURE:
;     Uses the 'spawn' command and 'find' command in Unix to determine if 
;     the path exist.
;
; MODIFICATION HISTORY:
;     2000-10-05 - written M. Cushing, Institute for Astronomy, UH
;     2002-01-25 - Modified to work with MacOS
;
function cpath,path,WIDGET_ID=widget_id,CANCEL=cancel

cancel = 0

;  Check parameters

if n_params() lt 1 then begin
    
    print, 'Syntax -  result = cpath(path,CANCEL=cancel)
    cancel = 1
    return, -1

endif
zparcheck, 'cpath', path, 1, 7, 0, 'String path name' 

;  If path eq '' then it should return the current directory.

if path eq '' then begin
    
    spawn,'pwd',result
    path = result[0]
    
endif

;  Check to make sure there is a trailing / if the path is not ''

case !version.os_family of 

    'unix': if strmid(path,0,1,/reverse_offset) ne '/' then path = path+'/'

    'MacOS': if strmid(path,0,1,/reverse_offset) ne ':' then path = path+':'

endcase

;  Make sure the path exists

catch, error

if error ne 0 then begin

    cancel = 1
    if n_elements(WIDGET_ID) ne 0 then begin

        ok = dialog_message('Path does not exist.',/error,$
                            dialog_parent=widget_id)

    endif
    return, -1

endif 
cd, CURRENT=current
cd, path

catch, /CANCEL
cd, current
return, path

end





