; NAME:
;     findSpeXflats
;
; PURPOSE:
;     To find the flat field images in a list of SpeX data.
;
; CATEGORY:
;     File I/O
;
; CALLING SEQUENCE:
;     result = findSpeXflats(files,MASK=mask,CANCEL=cancel)
;
; INPUTS:
;     files - A string (scalar or array) of posibble flat files.
;
; OUTUTS:
;     Returns an array of the files that are flat fields.
;
; KEYWORD PARAMETERS:
;     MASK   - On return, an array of 0s and 1s indicating which files 
;              are flats (0 = no, 1 = yes).
;     CANCEL - Set on return if there is a problem.
;
; PROCEDURES CALLED:
;     Requires the Astronomy User's Library.
;
; PROCEDURE:
;     Searches the headers of the files for the keywords,
;     QTH_LAMP, INC_LAMP, IR_SRC.
;
; MODIFICATION HISTORY:
;     2001-03-30 - written by M. Cushing, Institute for Astronomy, UH
;
function findspexflats,files,MASK=mask,CANCEL=cancel

cancel = 0

;  Check parameters

if n_params() lt 1 then begin
    
    print, 'Syntax -  result = findSpeXflats(files,MASK=mask,CANCEL=cancel)
    cancel = 1
    return, -1

endif
zparcheck, 'findSpeXflats', files, 1, 7 , [0,1], 'Files' 

n    = n_elements(files)
mask = intarr(n)

idx = 0
for i = 0, n-1 do begin

    hdr = headfits(files[i])
    QTH = strtrim(fxpar(hdr,'QTH_LAMP'),2)
    INC = strtrim(fxpar(hdr,'INC_LAMP'),2)
    IR  = strtrim(fxpar(hdr,'IR_SRC'),2)

    if QTH eq 'On' or INC eq 'On' or IR eq 'On' then begin

        mask[i] = 1
        idx = idx + 1
        flat = (idx eq 1) ? files[i]:[flat,files[i]]

    endif

endfor

return, flat

end






