; NAME:
;     fits2text
;
; PURPOSE:
;     To convert a SpeX FITS file to a text file
;
; CATEGORY:
;     Data Reduction
;
; CALLING SEQUENCE:
;     fits2text
;     fits2text,filename
;
; INPUTS:
;     filename - A string filename of a SpeX FITS file
;
; OUTUTS:
;     A text file with the root of filename+.txt.
;
; KEYWORD PARAMETERS:
;     None
;
; PROCEDURES CALLED:
;     Requires the Astronomy User's Library
;
; PROCEDURE:
;     Straight forward
;
; MODIFICATION HISTORY:
;     2001-09-29 - written M. Cushing, Institute for Astronomy, UH
;
pro fits2text,filename

if n_params() ne 1 then begin

    filename = ' '
    re       = ' '
    read, filename,PROMPT='Please enter a SpeX FITS file: '

endif

readspec,filename,spec,hdr,obsmode,start,stop,norders,naps,orders,$
  xunits,yunits,slith_pix,slith_arc,slitw_pix,slitw_arc,$
  airmass,CANCEL=cancel

npix = fxpar(hdr,'NAXIS1')

pos  = strpos(filename,'.fits')
root = strmid(filename,0,pos)

openw,lun,root+'.txt', /get_lun

for i = 0, n_elements(hdr)-1 do printf, lun, hdr[i]

for i = 0, npix[0]-1 do begin
    
    printf, lun,  strjoin( reform(spec[i,*,*],3*naps*norders),'  ' )
    
endfor
close, lun
free_lun, lun

end





