; NAME:
;     gethdrinfo
;
; PURPOSE:
;     To extract requested hdr info from a FITS header.
;
; CATEGORY:
;     Data Reduction
;
; CALLING SEQUENCE:
;     result = gethdrinfo(hdr,keywords)
;
; INPUTS:
;     hdr      - A FITS header.
;     keywords - A string array of keywords to extract.
;
; OUTUTS:
;     Returns a structure containing the keywords and their values.
;
; KEYWORD PARAMETERS:
;     STRING - If a variable is given, gethdrinfo will return a string
;              array of the values of the keywords.
;     CANCEL - Set on return if there is a problem
;
; PROCEDURES CALLED:
;     Requires the Astronomy User's Library
;
; PROCEDURE:
;     Straight forward
;
; MODIFICATION HISTORY:
;     2001-08-03 - Written by M. Cushing, Institute for Astronomy, UH
;
function gethdrinfo,hdr,keywords,STRING=string,CANCEL=cancel
;
cancel = 0

;  Check parameters

if n_params() lt 1 then begin
    
    cancel = 1
    print, 'Syntax - result = gethdrinfo(hdr,keywords,STRING=string,$'
    print, '                             CANCEL=cancel)'
    return,1

endif

zparcheck, 'gethdrinfo', hdr, 1,7,1, 'FITS hdr' 
nkeys  = n_elements(keywords)

if nkeys eq 0 then begin

    for i = 0, n_elements(hdr)-1 do begin

        if strmid(hdr[i],8,1) eq '=' then begin

            key = strjoin( strsplit( strtrim( strmid(hdr[i],0,8),2),'-',/EXTR))
            if i eq 0 then keywords = key else begin
                
                z = where(keywords eq key,count)
                if count eq 0 then keywords = (i eq 0) ? key:[keywords,key]

            endelse
        
        endif

    endfor

    keywords = [keywords,'HISTORY']
    nkeys = n_elements(keywords)

endif else zparcheck, 'gethdrinfo', keywords, 2,7,[0,1], 'Array of keywords' 

string = strarr(nkeys)

for i = 0, nkeys-1 do begin

    value = fxpar(hdr,keywords[i])
    if !err lt 0 then value = "Doesn't Exist"
    if (size(value))[0] gt 0 then value = strjoin(value,/SINGLE)
    string[i] = strtrim(value,2)
    key = strjoin( strsplit(keywords[i],'-',/EXTR))
    junk = (i eq 0) ? create_struct(key,value):create_struct(junk,key,value)

endfor

return, junk

end






