; NAME:
;     mklog
;
; PURPOSE:
;     To make an electronic log of a nights observations for SpeX.
;
; CATEGORY:
;     Data reduction
;
; CALLING SEQUENCE:
;     mklog,ifilename,ofilename
;
; INPUTS:
;     ifile - A string file name containing a list of the FITS files
;             that will be used to construct the log.
;
; OUTUTS:
;     ofile - A string file name of the log
;
; KEYWORD PARAMETERS:
;     None
;
; PROCEDURES CALLED:
;     Requires the Astronomy User's Library.
;
; PROCEDURE:
;     Reads the headers of the FITS files for the specified KEYWORDS.
;     This is hardwired for SpeX. 
;
; MODIFICATION HISTORY:
;     2000-02-20 - Written by M. Cushing, Institute for Astronomy, UH
;
pro mklog,ifilename,ofilename

if n_params() eq 0 then begin

    ifilename = ' '
    ofilename = ' '
    read, ifilename,PROMPT='Please enter name of file containing list of'+$
      ' FITS images: '
    read, ofilename,PROMPT='Please enter name of output log: '

endif

zparcheck, 'mklog', ifilename, 1, 7, 0, 'Input Filename'
zparcheck, 'mklog', ofilename, 2, 7, 0, 'Output Filename'

keywords = ['IRAFNAME','OBJECT','GRAT','ITIME','CO_ADDS','SLIT','AIRMASS',$
            'HA','COMMENT']
nkeywords = n_elements(keywords)

readcol,ifilename,names,FORMAT='A',/DEBUG
nfiles = n_elements(names)

info   = strarr(nfiles,nkeywords)

for i = 0, nfiles-1 do begin

    hdr       = headfits(names[i])
    result    = gethdrinfo(hdr,keywords,STRING=string)
    info[i,*] = string

endfor

format = '('
length = 0
for i = 0,nkeywords-1 do begin

    result = strlen(info[*,i])
    format = format+'2x,A'+strtrim(( strlen(keywords[i]) > max(result)),2)+','
    length = length + ( strlen(keywords[i]) > max(result))
    
endfor

format = strmid(format,0,strpos(format,',',/REVERSE_S))+')'

del = '-'
for i = 0,(length+2*nkeywords)-1 do del = del+'-'

openw, lun, ofilename,/GET_LUN

printf, lun, keywords,format=format
printf, lun, del
printf, lun, ' '
for i = 1, nfiles do begin

    if i mod 10 eq 0 then printf, lun, ' ' 
    printf, lun, info[i-1,*],format=format

endfor
free_lun, lun

end
