; NAME:
;     moments
; PURPOSE:
;     To compute statistics on a given vector.
;
; CATEGORY:
;     Statistics
;
; CALLING SEQUENCE:
;     moments,data,mean,var,stddev,skew,kurt,CANCEL=cancel
;
; INPUTS:
;     data   - Vector of data values.
;
; OUTUTS:
;     mean   - Mean
;     var    - Variance 
;     stddev - Standard 
;     skew   - Skewness
;     kurt   - Kurtosis   
;
; KEYWORD PARAMETERS:
;	DOUBLE - Set to compute in double precision
;       CANCEL - Set on return if there is a problem
;
; PROCEDURE:
;	Calls moment and computes the stddev.  Automatically searches
;	for NaNs.
;
pro moments,data,mean,var,stddev,skew,kurt,DOUBLE=double

cancel = 0

if n_params() lt 1 then begin
    
    print, 'Syntax - moments,data,mean,var,stddev,skew,kurt,CANCEL=cancel'
    cancel = 1
    return

endif

n = n_elements(data)

if n le 1 then begin
    
    print, 'Error:  data must have at least 2 elements.'
    return
    
endif
result  = moment(data,/NAN,DOUBLE=double)
mean    = result[0]
var     = result[1]
stddev  = sqrt(var)
skew    = result[2]
kurt    = result[3]

end





