; NAME:
;     readinstrfile
;
; PURPOSE:
;     To read a instrument file for Spextool.
;       
; CATEGORY:
;     Data Reduction
;
; CALLING SEQUENCE:
;     readinstrfile,filename,instr,irafname,gain,readnoise,itime,$
;                   coadds,ndrs,time,posangle,ha,airmass,nint,bdpxmk,keywords,$
;                   ncols,nrows,CANCEL=cancel
;
; INPUTS:
;     filename  - The name of a Spextool calibration file.
;
; OUTUTS:
;     instr     - Instrument name
;     irafname  - The FITS filename keyword (IRAFNAME)
;     gain      - The gain of the array
;     readnoise - The read noise of the detector
;     itime     - The integration time keyword
;     coadds    - The coadds keyword
;     ndrs      - The ndr keyword
;     time      - The time observed keyword
;     posangle  - The position angle keyword
;     ha        - The hour angle keyword
;     airmass   - The airmass keyword
;     nint      - The number of integer positions in the filenames
;     bdpxmk    - The name of the bad pixel mask stored in /Spextool/data
;     keywords  - An array of keywords to extract from the header
;
; KEYWORD PARAMETERS:    
;     CANCEL - Set on return if something is wrong.
;
; PROCEDURE'S USED:
;     Requires the Astronomy User's Library
;
; PROCEDURE:
;     Straight forward
;
; REVISION HISTORY:
;     20001-05-10 - Written by M. Cushing, Institute for Astronomy, UH
;
pro readinstrfile,filename,instr,irafname,gain,readnoise,itime,$
                  coadds,ndrs,time,posangle,ha,airmass,nint,bdpxmk,keywords,$
                  ncols,nrows,CANCEL=cancel

cancel = 0

;  Check parameters

if n_params() lt 1 then begin
    
    cancel = 1
    print, 'Syntax - readinstfile,filename,instr,irafname,gain,$'
    print, '                      readnoise,itime,coadds,ndrs,nint,bdpxmk,$'
    print, '                      keywords,CANCEL=cancel'
    return

endif

zparcheck, 'readinstrfile', filename, 1,7,0, 'Filename' 

line = ''
openr, lun, filename,/GET_LUN

readf, lun, line
instr = strtrim( (strsplit(line,'=',/EXTRACT))[1],2)

readf, lun, line
ncols = long( (strsplit(line,'=',/EXTRACT))[1])

readf, lun, line
nrows = long( (strsplit(line,'=',/EXTRACT))[1])

readf, lun, line
irafname = strtrim( (strsplit(line,'=',/EXTRACT))[1],2)

readf, lun, line
gain = float( (strsplit(line,'=',/EXTRACT))[1] )

readf, lun, line
readnoise = float( (strsplit(line,'=',/EXTRACT))[1] )

readf, lun, line
ITIME = strtrim( (strsplit(line,'=',/EXTRACT))[1],2 )

readf, lun, line
COADDS = strtrim( (strsplit(line,'=',/EXTRACT))[1],2 )

readf, lun, line
NDRS = strtrim( (strsplit(line,'=',/EXTRACT))[1],2 )

readf, lun, line
TIME = strtrim( (strsplit(line,'=',/EXTRACT))[1],2 )

readf, lun, line
POSANGLE = strtrim( (strsplit(line,'=',/EXTRACT))[1],2 )

readf, lun, line
HA = strtrim( (strsplit(line,'=',/EXTRACT))[1],2 )

readf, lun, line
AIRMASS = strtrim( (strsplit(line,'=',/EXTRACT))[1],2 )

readf, lun, line
nint = fix( (strsplit(line,'=',/EXTRACT))[1] )

readf, lun, line
bdpxmk = strtrim( (strsplit(line,'=',/EXTRACT))[1],2 )

readf, lun, line
keywords = strtrim( (strsplit(line,'=',/EXTRACT))[1],2 )

while not eof(lun) do begin 

    readf, lun, line
    keywords = [keywords,strtrim(line,2)]

endwhile

free_lun, lun




end
