; NAME:
;     setfocus
;
; PURPOSE:
;     To set the cursor focus in the coyote_field2 compound widget.
;
; CATEGORY:
;     Widgets
;
; CALLING SEQUENCE:
;     setfocus,field_id,CANCEL=cancel
;
; INPUTS:
;     field_id - Widget IDs of the coyote_field and text window.
;
; OUTUTS:
;     None
;
; KEYWORD PARAMETERS:
;     CANCEL - Set on return if there is a problem
;
; PROCEDURES CALLED:
;     Requires the Astronomy User's Library.
;     cfld
;
; PROCEDURE:
;     Sets the focus to a compound field widget created with
;     COYOTE_FIELD2 and places the cursor at the end of the text.  
;
; MODIFICATION HISTORY:
;     2000-08-23 - Written by M. Cushing, Institute for Astronomy, UH
;
pro setfocus,field_id,CANCEL=cancel

cancel = 0

if n_params() lt 1 then begin
    
    cancel = 1
    print, 'Syntax - setfocus,field_id,CANCEL=cancel'
    return

endif
zparcheck, 'setfocus',field_id, 1, [2,3,4,5], 1, 'field_id'

result = cfld(field_id,7,CANCEL=cancel)
if cancel then return
length = strlen(result)
widget_control, field_id[1], /INPUT_FOCUS
widget_control, field_id[1],set_text_select=length

end
