; NAME:
;     unrotate
;
; PURPOSE:
;     To un-rotate an image rotated using the IDL rountine rotate
;       
; CATEGORY:
;     data reduction
;
; CALLING SEQUENCE:
;     result = unrotate(image,rot,CANCEL=cancel)     
;
; INPUTS:
;     image - A 2-D image
;     rot   - The IDL rotation number
;
; OUTUTS:
;     Returns an unrotated version of image
;
; KEYWORD PARAMETERS:    
;     CANCEL    - Set on return if there is a problem
;
; PROCEDURES CALLED:
;     Requires the Astronomy User's Library.
;     Fanning ShowProgress Object
;
; PROCEDURE:
;     Obvious
;
; REVISION HISTORY:
;     2001-12-10 - Written by M. Cushing, Institute for Astronomy, UH
;
function unrotate,image,rot,CANCEL=cancel

cancel = 0

;  Check parameters

if n_params() ne 2 then begin
    
    print, 'Syntax - result = unrotate(image,rot,CANCEL=cancel)
    cancel = 1
    return,-1

endif
zparcheck, 'unrotate',image, 1, [2,3,4,5], 2, 'Image' 
zparcheck, 'unrotate',rot, 2, [2,3,4,5], 0, 'rot' 

case rot of 

    0: urimage = image

    1: urimage = rotate(image,3)
    
    2: urimage = rotate(image,2)

    3: urimage = rotate(image,1)

    4: urimage = rotate(image,4)

    5: urimage = rotate(rotate(image,3),4)

    6: urimage = rotate(rotate(image,2),4)

    7: urimage = rotate(rotate(image,1),4)

endcase

return, urimage


end



