; NAME:
;     writesky 
;
; PURPOSE:
;     To write a FITS SpeX sky image.
;
; CATEGORY:
;     Data reduction
;
; CALLING SEQUENCE:
;     writesky,sky,outname,hdrinfo,HISTORY=history,CANCEL=cancel
;
; INPUTS:
;     sky     - The 2-D sky image
;     outname - The output FITS name (fullpath included)
;     hdrinfo - A structure of keywords and values to write to the header
;
; OUTUTS:
;     Writes a FITS image to disk.
;
; KEYWORD PARAMETERS:
;     HISTORY - Set to a string containing a HISTORY statement to be
;               included in the header.  It will parsed into 70
;               character lines.
;
; PROCEDURES CALLED:
;     Requires the Astronomy User's Library.
;
; PROCEDURE:
;     Straight forward
;
; MODIFICATION HISTORY:
;     2000-08-20 - Written by M. Cushing, Institute for Astronomy, UH
;
pro writesky,sky,outname,hdrinfo,HISTORY=history,CANCEL=cancel

cancel = 0

;Check parameters

if n_params() lt 3 then begin

    cancel = 1
    print, 'Syntax - writesky,sky,outname,hdrinfo,HISTORY=history,$'
    print, '                  CANCEL=cancel'
    return

endif
zparcheck, 'writesky', sky, 1, [2,3,4,5], 2, 'Sky Image' 
zparcheck, 'writesky', outname, 2, 7, 0, 'Output Name' 
zparcheck, 'writesky', hdrinfo, 3, 8, [0,1], 'Header Info' 

;  Make hdr with hdrinfo in it.

fxhmake,hdr,sky

ntags = n_tags(hdrinfo)
names = tag_names(hdrinfo)

for i = 0, ntags - 1 do fxaddpar,hdr,names[i],hdrinfo.(i)

if n_elements(HISTORY) ne 0 then begin

    length = strlen(history)
    loop = ceil(float(length)/70.)
    for i = 0, loop-1 do begin

        hist = strmid(history,70*i,70)
        fxaddpar,hdr,'HISTORY',hist

    endfor

endif

writefits,outname,sky,hdr

end
