; NAME:
;     xmkinstrfile
;
; PURPOSE:
;     To make an instrument file for Spextool
;       
; CATEGORY:
;     Data reduction
;
; CALLING SEQUENCE:
;     xmkinstrfile
;
; INPUTS:
;     None
; OUTUTS:
;     Writes a text file (Instrument Name.dat) to Spextool/data
;
; KEYWORD PARAMETERS:    
;     None
;
; PROCEDURES CALLED:
;     Requires the Astronomy User's Library
;
; PROCEDURE:
;     Load an image in.  Then file out the fields in the left columns
;     with the relavent data.  Then click the FITS keywords you want
;     to be saved in Spextool.  NOTE-Any keyword entered in the left
;     column must be checked in the FITS header.
;
; MODIFICATION HISTORY:
;     2001-11-05 - Written by M. Cushing, Institute for Astronomy, UH
;
;******************************************************************************
;
; ----------------------------Support procedures------------------------------ 
;
;******************************************************************************
;
;
;******************************************************************************
;
pro xmkinstrfile_startup

common xmkinstrfile_state, state

;  get Spextool path.

case !version.os_family of 

    'unix': sep = ':'

    'MacOS': sep = ','

endcase

case !version.os_family of 

    'unix': dirsep = '/'

    'MacOS': dirsep = ':'

endcase

last   = strpos(!path,'Spextool')
first  = strpos(!path,sep,last,/REVERSE_SEARCH)
result = strmid(!path,first+1,last-first+7)

path = cpath(result,CANCEL=cancel)
if cancel then return

mkct
textfont   = '-adobe-helvetica-medium-r-normal--0-0-75-75-p-0-iso8859-1'
buttonfont = '-adobe-helvetica-bold-r-normal--14-140-75-75-p-82-iso8859-1'

;  Build the structures which will hold the important info.

w = {airmass_fld:[0L,0L],$
     badpixmask_fld:[0,0],$
     calfile_fld:[0,0],$
     gain_fld:[0,0],$
     ha_fld:[0L,0L],$
     header_base:0L,$
     coadds_fld:[0,0],$
     filename_fld:[0,0],$
     ifile_fld:[0L,0L],$
     instr_fld:[0,0],$
     instrfile_fld:[0,0],$
     itime_fld:[0,0],$
     ncols_fld:[0,0],$
     ndr_fld:[0,0],$
     nrows_fld:[0,0],$
     nint_fld:[0,0],$
     posangle_fld:[0L,0L],$
     readnoise_fld:[0,0],$
     sep:dirsep,$
     time_fld:[0L,0L],$
     xmkinstrfile_base:0L}

r = {path:path,$
     rotation:0L}

d = {hdr:ptr_new(strarr(2)),$
     mask:ptr_new(fltarr(2))}

state = {w:w,r:r,d:d}

state.w.xmkinstrfile_base = widget_base(TITLE='XMake Instrument File',$
                                        /COLUMN)

   quit_button = widget_button(state.w.xmkinstrfile_base,$
                               FONT=buttonfont,$
                               VALUE='Quit',$
                               UVALUE='Quit')

   row_base = widget_base(state.w.xmkinstrfile_base,$
                          /ROW)

      info_base = widget_base(row_base,$
                              /BASE_ALIGN_LEFT,$
                              /SCROLL,$
                              XSIZE=250,$
                              X_SCROLL_SIZE=270,$
                              Y_SCROLL_SIZE=270,$
                              /COLUMN)
      
         box1_base = widget_base(info_base,$
                                 /COLUMN,$
                                 FRAME=1)
         
            row = widget_base(box1_base,$
                              /ROW,$
                              /BASE_ALIGN_CENTER)
            
               input = widget_button(row,$
                                     FONT=buttonfont,$
                                     VALUE='Input Image',$
                                     UVALUE='Input Image',$
                                     EVENT_PRO='xmkinstrfile_event')
               
               input_fld = coyote_field2(row,$
                                         LABELFONT=buttonfont,$
                                         FIELDFONT=textfont,$
                                         TITLE=':',$
                                         UVALUE='Input Image Field',$
                                         XSIZE=15,$
                                         EVENT_PRO='xmkinstrfile_event',$
                                         /CR_ONLY,$
                                         TEXTID=textid)
               state.w.ifile_fld = [input_fld,textid]
               
            load = widget_button(box1_base,$
                                 VALUE='Load Image',$
                                 UVALUE='Load Image',$
                                 FONT=buttonfont,$
                                 EVENT_PRO='xmkinstrfile_event')
            
            keywords_base = widget_base(info_base,$
                                        /COLUMN,$
                                        FRAME=1,$
                                        /BASE_ALIGN_RIGHT)
            

            instrument = coyote_field2(keywords_base,$
                                       LABELFONT=buttonfont,$
                                       FIELDFONT=textfont,$
                                       TITLE='Instrument Name:',$
                                       UVALUE= 'Instrument Name',$
                                       XSIZE=12,$
                                       EVENT_PRO= 'xmkinstrfile_event',$
                                       /CR_ONLY,$
                                       TEXTID=textid)
            state.w.instr_fld = [instrument,textid]

            ncols = coyote_field2(keywords_base,$
                                  LABELFONT=buttonfont,$
                                  FIELDFONT=textfont,$
                                  TITLE='Ncols:',$
                                  UVALUE= 'Ncols',$
                                  XSIZE=12,$
                                  VALUE='1024',$
                                  EVENT_PRO= 'xmkinstrfile_event',$
                                  /CR_ONLY,$
                                  TEXTID=textid)
            state.w.ncols_fld = [ncols,textid]

            nrows = coyote_field2(keywords_base,$
                                  LABELFONT=buttonfont,$
                                  FIELDFONT=textfont,$
                                  TITLE='Nrows:',$
                                  UVALUE= 'Nrows',$
                                  XSIZE=12,$
                                  VALUE='1024',$
                                  EVENT_PRO= 'xmkinstrfile_event',$
                                  /CR_ONLY,$
                                  TEXTID=textid)
            state.w.nrows_fld = [nrows,textid]

            filename = coyote_field2(keywords_base,$
                                     LABELFONT=buttonfont,$
                                     FIELDFONT=textfont,$
                                     TITLE='Filename Keyword:',$
                                     UVALUE= 'Filename Keyword',$
                                     VALUE='IRAFNAME',$
                                     XSIZE=12,$
                                     EVENT_PRO= 'xmkinstrfile_event',$
                                     /CR_ONLY,$
                                     TEXTID=textid)
            state.w.filename_fld = [filename,textid]

            itime = coyote_field2(keywords_base,$
                                  LABELFONT=buttonfont,$
                                  FIELDFONT=textfont,$
                                  TITLE='ITIME Keyword:',$
                                  UVALUE= 'ITIME Keyword',$
                                  XSIZE=12,$
                                  EVENT_PRO= 'xmkinstrfile_event',$
                                  /CR_ONLY,$
                                  TEXTID=textid)
            state.w.itime_fld = [itime,textid]

            coadd = coyote_field2(keywords_base,$
                                  LABELFONT=buttonfont,$
                                  FIELDFONT=textfont,$
                                  TITLE='COADDS Keyword:',$
                                  UVALUE= 'COADDS Keyword',$
                                  VALUE='None',$
                                  XSIZE=12,$
                                  EVENT_PRO= 'xmkinstrfile_event',$
                                  /CR_ONLY,$
                                  TEXTID=textid)
            state.w.coadds_fld = [coadd,textid]

            NDR = coyote_field2(keywords_base,$
                                LABELFONT=buttonfont,$
                                FIELDFONT=textfont,$
                                TITLE='NDR Keyword:',$
                                VALUE='None',$
                                UVALUE= 'NDR Keyword',$
                                XSIZE=12,$
                                EVENT_PRO= 'xmkinstrfile_event',$
                                /CR_ONLY,$
                                TEXTID=textid)
            state.w.ndr_fld = [ndr,textid]

            time = coyote_field2(keywords_base,$
                                 LABELFONT=buttonfont,$
                                 FIELDFONT=textfont,$
                                 TITLE='Time Keyword:',$
                                 VALUE='None',$
                                 UVALUE= 'Time Keyword',$
                                 XSIZE=12,$
                                 EVENT_PRO= 'xmkinstrfile_event',$
                                 /CR_ONLY,$
                                 TEXTID=textid)
            state.w.time_fld = [time,textid]

            posangle = coyote_field2(keywords_base,$
                                     LABELFONT=buttonfont,$
                                     FIELDFONT=textfont,$
                                     TITLE='Posangle Keyword:',$
                                     VALUE='None',$
                                     UVALUE= 'Posangle Keyword',$
                                     XSIZE=12,$
                                     EVENT_PRO= 'xmkinstrfile_event',$
                                     /CR_ONLY,$
                                     TEXTID=textid)
            state.w.posangle_fld = [posangle,textid]

            ha = coyote_field2(keywords_base,$
                               LABELFONT=buttonfont,$
                               FIELDFONT=textfont,$
                               TITLE='HA Keyword:',$
                               VALUE='None',$
                               UVALUE= 'HA Keyword',$
                               XSIZE=12,$
                               EVENT_PRO= 'xmkinstrfile_event',$
                               /CR_ONLY,$
                               TEXTID=textid)
            state.w.ha_fld = [ha,textid]
            
            airmass = coyote_field2(keywords_base,$
                                    LABELFONT=buttonfont,$
                                    FIELDFONT=textfont,$
                                    TITLE='Airmass Keyword:',$
                                    VALUE='None',$
                                    UVALUE= 'Airmass Keyword',$
                                    XSIZE=12,$
                                    EVENT_PRO= 'xmkinstrfile_event',$
                                    /CR_ONLY,$
                                    TEXTID=textid)
            state.w.airmass_fld = [airmass,textid]

            GAIN = coyote_field2(keywords_base,$
                                 LABELFONT=buttonfont,$
                                 FIELDFONT=textfont,$
                                 TITLE='Gain:',$
                                 VALUE='13',$
                                 UVALUE= 'Gain',$
                                 XSIZE=12,$
                                 EVENT_PRO= 'xmkinstrfile_event',$
                                 /CR_ONLY,$
                                 TEXTID=textid)
            state.w.gain_fld = [gain,textid]

            readnoise = coyote_field2(keywords_base,$
                                      LABELFONT=buttonfont,$
                                      FIELDFONT=textfont,$
                                      TITLE='Read Noise:',$
                                      VALUE='13',$
                                      UVALUE= 'Read Noise',$
                                      XSIZE=12,$
                                      EVENT_PRO= 'xmkinstrfile_event',$
                                      /CR_ONLY,$
                                      TEXTID=textid)
            state.w.readnoise_fld = [readnoise,textid]

            NINT = coyote_field2(keywords_base,$
                                 LABELFONT=buttonfont,$
                                 FIELDFONT=textfont,$
                                 TITLE='Nint:',$
                                 VALUE='4',$
                                 UVALUE= 'Nint',$
                                 XSIZE=12,$
                                 EVENT_PRO= 'xmkinstrfile_event',$
                                 /CR_ONLY,$
                                 TEXTID=textid)
            state.w.nint_fld = [NINT,textid]

            badpix = coyote_field2(keywords_base,$
                                   LABELFONT=buttonfont,$
                                   FIELDFONT=textfont,$
                                   TITLE='Bad Pixel Mask:',$
                                   VALUE='None',$
                                   UVALUE= 'Bad Pixel Mask',$
                                   XSIZE=12,$
                                   EVENT_PRO= 'xmkinstrfile_event',$
                                   /CR_ONLY,$
                                   TEXTID=textid)
            state.w.badpixmask_fld = [badpix,textid]

      state.w.header_base = widget_base(row_base,$
                                        /FRAME,$
                                        /SCROLL,$
                                        X_SCROLL_SIZE=550,$
                                        Y_SCROLL_SIZE=500,$
                                        XSIZE=550,$
                                        YSIZE=1000,$
                                        /COLUMN)
   mkfile = widget_button(state.w.xmkinstrfile_base,$
                          FONT=buttonfont,$
                          VALUE='Make Instrument File',$
                          UVALUE='Make Instrument File')


; Get things running.

centertlb,state.w.xmkinstrfile_base
      
widget_control, state.w.xmkinstrfile_base, /Realize

; Start the Event Loop. This will be a non-blocking program.

XManager, 'xmkinstrfile', $
  state.w.xmkinstrfile_base, $
  /No_Block,$
  cleanup='xmkinstrfile_cleanup'

end
;
;******************************************************************************
;
pro xmkinstrfile_bg

common xmkinstrfile_state

widget_control, state.w.header_base, UPDATE=0

bg = cw_bgroup(state.w.header_base,$
               (*state.d.hdr),$
               /RETURN_INDEX,$
               UVALUE='Keywords',$
               /NONEXCLUSIVE)

widget_control, state.w.header_base, UPDATE=1
*state.d.mask = intarr( n_elements( *state.d.hdr) )

end
;
;******************************************************************************
;
pro xmkinstrfile_cleanup,event

common xmkinstrfile_state

ptr_free, state.d.hdr
ptr_free, state.d.mask

state = 0B

end
;
;******************************************************************************
;
pro xmkinstrfile_loadimage

common xmkinstrfile_state

fitsfile = cfld(state.w.ifile_fld,7,/EMPTY,CANCEL=cancel)
if cancel then return

image = readfits(fitsfile,hdr)

s = size(image)
ncols = s[1]
nrows = s[2]

*state.d.hdr = hdr
str = 'X Make Instrument File - '+strmid(fitsfile,strpos(fitsfile,$
                                                         'state.w.sep',$
                                                         /REVERSE_S)+1)

widget_control, state.w.xmkinstrfile_base, tlb_set_title = str
xmkinstrfile_bg

end
;
;******************************************************************************
;
pro xmkinstrfile_makefile

common xmkinstrfile_state

instr = cfld(state.w.instr_fld,7,/EMPTY,CANCEL=cancel)
if cancel then return
ncols = cfld(state.w.ncols_fld,3,/EMPTY,CANCEL=cancel)
if cancel then return
nrows = cfld(state.w.nrows_fld,3,/EMPTY,CANCEL=cancel)
if cancel then return
filename = cfld(state.w.filename_fld,7,/EMPTY,CANCEL=cancel)
if cancel then return
gain = cfld(state.w.gain_fld,4,/EMPTY,CANCEL=cancel)
if cancel then return
readnoise = cfld(state.w.readnoise_fld,4,/EMPTY,CANCEL=cancel)
if cancel then return
itime = cfld(state.w.itime_fld,7,/EMPTY,CANCEL=cancel)
if cancel then return
coadds = cfld(state.w.coadds_fld,7,/EMPTY,CANCEL=cancel)
if cancel then return
ndr = cfld(state.w.ndr_fld,7,/EMPTY,CANCEL=cancel)
if cancel then return
nint = cfld(state.w.nint_fld,3,/EMPTY,CANCEL=cancel)
if cancel then return
bdpx = cfld(state.w.badpixmask_fld,7,/EMPTY,CANCEL=cancel)
if cancel then return

time = cfld(state.w.time_fld,7,/EMPTY,CANCEL=cancel)
if cancel then return
posangle = cfld(state.w.posangle_fld,7,/EMPTY,CANCEL=cancel)
if cancel then return
ha = cfld(state.w.ha_fld,7,/EMPTY,CANCEL=cancel)
if cancel then return
airmass = cfld(state.w.airmass_fld,7,/EMPTY,CANCEL=cancel)
if cancel then return

z    = where(*state.d.mask eq 1,count)
if count eq 0 then begin

    ok = dialog_message('Please select FITS header keywords',$
                        /ERROR,DIALOG_PARENT=state.w.xmkinstrfile_base)

    return

endif
chdr = (*state.d.hdr)[z]
keys = strarr(count)


for i = 0, count-1 do keys[i] = strtrim( strmid(chdr[i],0,8),2 )

;  get Spextool path.

case !version.os_family of 

    'unix': sep = ':'

    'MacOS': sep = ','

endcase

last   = strpos(!path,'Spextool')
first  = strpos(!path,sep,last,/REVERSE_SEARCH)
result = strmid(!path,first+1,last-first+7)

path = cpath(result,CANCEL=cancel)
if cancel then return


openw,lun, filepath(instr+'.dat',ROOT_DIR=path,SUBDIR='data'), /GET_LUN

printf, lun, 'INSTRUMENT='+strtrim(instr,2)
printf, lun, 'NCOLS='+strtrim(ncols,2)
printf, lun, 'NROWS='+strtrim(nrows,2)
printf, lun, 'FILENAME='+strtrim(filename,2)
printf, lun, 'GAIN='+strtrim(gain,2)
printf, lun, 'READNOISE='+strtrim(readnoise,2)
printf, lun, 'ITIME='+strtrim(itime,2)
printf, lun, 'COADDS='+strtrim(coadds,2)
printf, lun, 'NDR='+strtrim(ndr,2)
printf, lun, 'TIME='+strtrim(time,2)
printf, lun, 'POSANGLE='+strtrim(posangle,2)
printf, lun, 'HA='+strtrim(ha,2)
printf, lun, 'AIRMASS='+strtrim(airmass,2)
printf, lun, 'NINT='+strtrim(nint,2)
printf, lun, 'BADPIXMASK='+strtrim(bdpx,2)
printf, lun, 'KEYWORDS='+strtrim(keys[0],2)
printf, lun, '         '+strtrim( rotate(keys[1:*],4),2 )

free_lun, lun


end
;
;******************************************************************************
;
;   ---------------------------Event Handlers------------------------------ 
;
;******************************************************************************
;
pro xmkinstrfile_event,event

common xmkinstrfile_state

widget_control, event.id, get_uvalue = event_name

widget_control, /hourglass
case event_name of 

    'Airmass Keyword': setfocus,state.w.gain_fld
    
    'Bad Pixel Mask': 

    'COADDS Keyword': setfocus,state.w.ndr_fld

    'Gain': setfocus,state.w.readnoise_fld
    
    'HA Keyword': setfocus,state.w.airmass_fld

    'Filename Keyword': setfocus,state.w.itime_fld

    'Input Image': begin

        obj = dialog_pickfile(DIALOG_PARENT=state.w.xmkinstrfile_base,$
                              /MUST_EXIST,FILTER='*.fits')
        if obj eq '' then goto, cont
        widget_control,state.w.ifile_fld[1],SET_VALUE = strtrim(obj,2)
        setfocus,state.w.ifile_fld

    end

    'Instrument Name': setfocus,state.w.ncols_fld

    'ITIME Keyword': setfocus,state.w.coadds_fld

    'Keywords': (*state.d.mask)[event.value] = event.select

    'Load Image': xmkinstrfile_loadimage

    'Make Instrument File': xmkinstrfile_makefile

    'Ncols': setfocus,state.w.nrows_fld

    'Nrows': setfocus, state.w.filename_fld

    'NDR Keyword': setfocus,state.w.time_fld

    'Nint': setfocus,state.w.badpixmask_fld

    'Posangle Keyword': setfocus,state.w.ha_fld

    'Read Noise': setfocus,state.w.nint_fld

    'Rotation': begin

        wset,state.r.plotwin_wid
        tv, rotate(*state.d.image,event.index)
        state.r.rotation = event.index

    end

    'Time Keyword': setfocus,state.w.posangle_fld

    'Quit':  widget_control, state.w.xmkinstrfile_base, /destroy

    else:

endcase
cont:

end
;
;******************************************************************************
;
pro xmkinstrfile

xmkinstrfile_startup


end


