; NAME:
;     xsmoothspec
;
; PURPOSE:
;     To smoothspec
;       
; CATEGORY:
;     Data reduction
;
; CALLING SEQUENCE:
;     xsmoothspec
;
; INPUTS:
;     None
;
; OUTUTS:
;     Writes a FITS or text file to disk
;
; KEYWORD PARAMETERS:    
;     None
;
; PROCEDURES CALLED:
;     Requires the Astronomy User's Libray
;     Alot
;
; PROCEDURE:
;     Reads the FITS header and creates a gaussian kernel of 
;     FWHM = slit width in pixels and then smooths the spectra and 
;     propagates the errors.
;
; MODIFICATION HISTORY:
;     2001-09-29 - Written by M. Cushing, Institute for Astronomy, UH
;
;******************************************************************************
;
; ------------------------------Event Handlers-------------------------------- 
;
;******************************************************************************
;
pro xsmoothspec_event, event

widget_control, event.top, GET_UVALUE = state, /NO_COPY
widget_control, event.id,  GET_UVALUE = uvalue
widget_control, /HOURGLASS

case uvalue of

    'File Name': begin

        path =dialog_pickfile(DIALOG_PARENT=state.w.xsmoothspec_base,$
                              /MUST_EXIST)

        if path ne '' then begin

            widget_control,state.w.filename_fld[1],SET_VALUE = path

        endif

    end

    'Load Spectrum': xsmoothspec_loadspec,state

    'Output Format': begin

        if event.value eq 'Text' then state.r.textoutput=event.select
        if event.value eq 'FITS' then state.r.fitsoutput=event.select

    end

    'Path Button': begin

        path= dialog_pickfile(/DIRECTORY,$
                              DIALOG_PARENT=state.w.xsmoothspec_base,$
                              TITLE='Select Path',/MUST_EXIST)
        if path ne '' then begin
            
            path = cpath(path,WIDGET_ID=state.w.xsmoothspec_base,CANCEL=cancel)
            if cancel then return
            widget_control,state.w.path_fld[1],SET_VALUE = path
            setfocus,state.w.path_fld

        endif

    end

    'Quit': begin

        widget_control, event.top, /destroy
        goto, getout
        
    end

    'Smooth Spectra': xsmoothspec_smoothspec,state

    'Smooth Type': begin

        widget_control, state.w.resa_base, MAP=0
        widget_control, state.w.resb_base, MAP=0

        if event.value eq 'Smooth by Slit' then begin

            state.r.smoothtype = event.value
            widget_control, state.w.resa_base, MAP=1

        endif
        if event.value eq 'Change <R>' then begin

            state.r.smoothtype = event.value
            widget_control, state.w.resb_base, MAP=1
            
        endif
    end

    'Spectra File Button': begin
                
        path = cfld(state.w.path_fld,7,CANCEL=cancel)
        if cancel then return
        if path ne '' then path = cpath(path,$
                                        WIDGET_ID=state.w.xsmoothspec_base,$
                                        CANCEL=cancel)

        fullpath = dialog_pickfile(DIALOG_PARENT=state.w.xsmoothspec_base,$
                                   PATH=path,/MUST_EXIST,FILTER='*.fits')
        
        if fullpath ne '' then begin
            
            widget_control,state.w.specfiles_fld[1],$
              set_value = strmid(fullpath,$
                                 strpos(fullpath,'/',/REVERSE_S)+1)
            
        endif

    end

    'Spectra Files Field': setfocus,state.w.outfile_fld

    else:

endcase

;  Put state variable into the user value of the top level base.
 
cont: 
widget_control, state.w.xsmoothspec_base, SET_UVALUE=state, /NO_COPY
getout:

end
;
;******************************************************************************
;
; ----------------------------Support procedures------------------------------ 
;
;******************************************************************************
;
pro xsmoothspec_cleanup,xsmoothspec_base

widget_control, xsmoothspec_base, GET_UVALUE = state, /NO_COPY
if n_elements(state) ne 0 then state = 0B

end
;
;******************************************************************************
;
pro xsmoothspec_loadspec,state

path = cfld(state.w.path_fld,7,CANCEL=cancel)
if cancel then return
if path ne ''  then path = cpath(path,WIDGET_ID=state.w.xsmoothspec_base,$
                                 CANCEL=cancel)
if cancel then return

file = cfld(state.w.specfiles_fld,7,/EMPTY,CANCEL=cancel)
if cancel then return
file = cfile(path+file,WIDGET_ID=state.w.xsmoothspec_base,CANCEL=cancel)
if cancel then return

;  Read and smooth spectra

readspec,file,spec,hdr,obsmode,start,stop,norders,naps,orders,$
  xunits,yunits,slith_pix,slith_arc,slitw_pix,slitw_arc,$
  airmass,CANCEL=cancel

*state.r.hdr    = hdr
*state.r.spec   = spec
state.r.norders = norders
state.r.naps    = naps
state.r.start   = start
state.r.stop    = stop
*state.r.orders = orders
state.r.xunits = xunits
state.r.yunits = yunits
state.r.slitw_pix = slitw_pix

if obsmode eq 'LongXD1.9' or obsmode eq 'LongXD2.1' or obsmode eq 'LongXD2.3' then obsmode = 'LongXD'

case obsmode of 

    'ShortXD': begin

        state.r.resperpix = 4000.
        nsigma = sqrt(2.)*slitw_pix
        label = 'Original <R> = '+string(4000./slitw_pix,format='(i4.4)')+$
          ',   New <R> = '+string(4000./nsigma,format='(i4.4)')
        widget_control, state.w.res_lbl,SET_VALUE=label
        state.r.maxres = 4000./sqrt(slitw_pix^2+1)
        widget_control, state.w.maxres_lbl,SET_VALUE='< '+$
          string(state.r.maxres,format='(i4.4)')

    end

    'LongXD': begin
    
        state.r.resperpix = 5000.
        nsigma = sqrt(2.)*slitw_pix
        label = 'Original <R> = '+string(5000./slitw_pix,format='(i4.4)')+$
          ',   New <R> = '+string(5000./nsigma,format='(i4.4)')
        widget_control, state.w.res_lbl,SET_VALUE=label
        state.r.maxres = 5000./sqrt(slitw_pix^2+1)
        widget_control, state.w.maxres_lbl,SET_VALUE='< '+$
          string(state.r.maxres,format='(i4.4)')

    end

    else: 


endcase

end
;
;******************************************************************************
;
pro xsmoothspec_smoothspec,state


path = cfld(state.w.path_fld,7,CANCEL=cancel)
if cancel then return
if path ne ''  then path = cpath(path,WIDGET_ID=state.w.xsmoothspec_base,$
                                 CANCEL=cancel)
if cancel then return


ofile = cfld(state.w.outfile_fld,7,/EMPTY,CANCEL=cancel)
if cancel then return

if state.r.smoothtype eq 'Smooth by Slit' then begin

    FWHM=state.r.slitw_pix
    res = state.r.resperpix/(sqrt(2)*state.r.slitw_pix)

endif else begin


    res = cfld(state.w.res_fld,4,/EMPTY,CANCEL=cancel)
    if cancel then return
    res = crange(res,[0,state.r.maxres],'<R>',/KLE,$
                 WIDGET_ID=state.w.xsmoothspec_base,CANCEL=cancel)
    if cancel then return
    FWHM = state.r.resperpix/res

endelse
spec = (*state.r.spec)

for i = 0, state.r.norders-1 do begin

    for j = 0, state.r.naps-1 do begin

        z = where(finite((*state.r.spec)[*,1,i*state.r.naps+j]) eq 1)
        convolvespec,findgen(state.r.stop-state.r.start+1),$
          (*state.r.spec)[z,1,i*state.r.naps+j],FWHM,cflux,cerror,$
          ERROR=(*state.r.spec)[z,2,i*state.r.naps+j],CANCEL=cancel

        spec[z,1,i*state.r.naps+j] = cflux
        spec[z,2,i*state.r.naps+j] = cerror

    endfor

endfor

;  Write results to disk

hdr = *state.r.hdr
hist = 'These spectra have been convolved with a Gaussain of FWHM='+$
  strcompress(FWHM,/RE)+'.'
fxaddpar,hdr,'RES',res
fxaddpar,hdr,'HISTORY',hist

if state.r.fitsoutput then writefits,path+ofile+'.fits',spec,hdr

if state.r.textoutput then begin

    npix = fxpar(hdr,'NAXIS1')
    openw,lun,path+ofile+'.txt', /GET_LUN

    for i = 0, n_elements(hdr)-1 do printf, lun, hdr[i]

    for i = 0, npix[0]-1 do begin

        printf, lun,  strjoin( reform(spec[i,*,*],$
                                      3*state.r.naps*state.r.norders),'  ' )

    endfor
    close, lun
    free_lun, lun

endif

xvspec,spec,state.r.norders,state.r.naps,$
  ORDERS=*state.r.orders,XUNITS=state.r.xunits,YUNITS=state.r.yunits,$
  HDR=hdr

end
;
;******************************************************************************
;
pro xsmoothspec,instrfile

mkct

;  Determine the instrument in use, default is SpeX.

if n_elements(instrfile) eq 0 then instrfile = 'SpeX.dat'

last   = strpos(!path,'Spextool')
first  = strpos(!path,':',last,/REVERSE_SEARCH)
result = strmid(!path,first+1,last-first+7)

path = cpath(result,CANCEL=cancel)
if cancel then return

readinstrfile,path+'data/'+instrfile,instr,irafname,idl_rot,gain,readnoise,$
  itime,coadds,ndrs,time,posangle,ha,airmass,nint,bdpxmk,keywords

;  Set the fonts

textfont   = '-adobe-helvetica-medium-r-normal--0-0-75-75-p-0-iso8859-1'
buttonfont = '-adobe-helvetica-bold-r-normal--14-140-75-75-p-82-iso8859-1'

;  Build three structures which will hold important info.
;  w - contains info pertaining to widget operations.
;  r - contains info pertaining to the reduction process.
;  d - contains all of the data.

w = {path_fld:[0L,0L],$
     filename_fld:[0L,0L],$
     maxres_lbl:0L,$
     outfile_fld:[0L,0L],$
     resa_base:0L,$
     resb_base:0L,$
     res_lbl:0L,$
     res_fld:[0L,0L],$
     specfiles_fld:[0L,0L],$
     xsmoothspec_base:0L}

r = {spec:ptr_new(fltarr(2)),$
     hdr:ptr_new(fltarr(2)),$
     start:0,$
     orders:ptr_new(fltarr(2)),$
     stop:0,$
     resperpix:0.,$
     smoothtype:'Smooth by Slit',$
     slitw_pix:0.,$
     maxres:0.,$
     norders:0,$
     naps:0,$
     fitsoutput:1,$
     xunits:'',$
     yunits:'',$
     textoutput:0}

state = {w:w,r:r}

;  Build the widget.

state.w.xsmoothspec_base = widget_base(title='Xsmoothspec', $
                                       /COLUMN,$
                                       /TLB_SIZE_EVENTS)

   quit_button = widget_button(state.w.xsmoothspec_base,$
                               FONT=buttonfont,$
                               VALUE='Quit',$
                               EVENT_PRO='xsmoothspec_event',$
                               UVALUE='Quit')

   text = widget_text(state.w.xsmoothspec_base,$
                      value='To be used on unsmoothed data only.')


   box1_base = widget_base(state.w.xsmoothspec_base,$
                           /COLUMN,$
                           FRAME=1)
   
      row = widget_base(box1_base,$
                        /ROW,$
                        /BASE_ALIGN_CENTER)
      
         button = widget_button(row,$
                                FONT=buttonfont,$
                                VALUE='Path',$
                                UVALUE='Path Button',$
                                EVENT_PRO='xsmoothspec_event')
         
         field = coyote_field2(row,$
                               LABELFONT=buttonfont,$
                               FIELDFONT=textfont,$
                               TITLE=':',$
                               UVALUE='Path Field',$
                               XSIZE=30,$
                               EVENT_PRO='xsmoothspec_event',$
                               /CR_ONLY,$
                               TEXTID=textid)
         state.w.path_fld = [field,textid]               
         
      row = widget_base(box1_base,$
                        /ROW,$
                        /BASE_ALIGN_CENTER)
      
         button = widget_button(row,$
                                FONT=buttonfont,$
                                VALUE='Spectra File',$
                                UVALUE='Spectra File Button',$
                                EVENT_PRO='xsmoothspec_event')
         
         field = coyote_field2(row,$
                               LABELFONT=buttonfont,$
                               FIELDFONT=textfont,$
                               TITLE=':',$
                               UVALUE='Spectra Files Field',$
                               XSIZE=25,$
                               EVENT_PRO='xsmoothspec_event',$
                               /CR_ONLY,$
                               TEXTID=textid)
         state.w.specfiles_fld = [field,textid]

      load_button = widget_button(box1_base,$
                                  FONT=buttonfont,$
                                  VALUE='Load Spectrum',$
                                  UVALUE='Load Spectrum')

   box2_base = widget_base(state.w.xsmoothspec_base,$
                           /COLUMN,$
                           FRAME=1)

     smooth_bg = cw_bgroup(box2_base,$
                           FONT=buttonfont,$
                           ['Smooth by Slit','Change <R>'],$
                           /ROW,$
                           /RETURN_NAME,$
                           /NO_RELEASE,$
                           /EXCLUSIVE,$
                           LABEL_LEFT='',$
                           UVALUE='Smooth Type',$
                           SET_VALUE=0)

     row = widget_base(box2_base)

        state.w.resa_base = widget_base(row,$
                                        /ROW,$
                                        /BASE_ALIGN_CENTER)

           state.w.res_lbl = widget_label(state.w.resa_base,$
                                          /DYNAMIC_RESIZE,$
                                          FONT=buttonfont,$
                                          VALUE='Resolution: ')
        
        state.w.resb_base = widget_base(row,$
                                        /ROW,$
                                        /BASE_ALIGN_CENTER,$
                                        MAP=0)

           field = coyote_field2(state.w.resb_base,$
                                 LABELFONT=buttonfont,$
                                 FIELDFONT=textfont,$
                                 TITLE='<R> = ',$
                                 UVALUE='<R>',$
                                 XSIZE=10,$
                                 EVENT_PRO='xsmoothspec_event',$
                                 /CR_ONLY,$
                                 TEXTID=textid)
           state.w.res_fld = [field,textid] 

           state.w.maxres_lbl = widget_label(state.w.resb_base,$
                                             /DYNAMIC_RESIZE,$
                                             FONT=buttonfont,$
                                             VALUE=' < ')
           
   box3_base = widget_base(state.w.xsmoothspec_base,$
                           /COLUMN,$
                           FRAME=1)

      outformat_bg = cw_bgroup(box3_base,$
                               FONT=buttonfont,$
                               ['FITS','Text'],$
                               /ROW,$
                               /RETURN_NAME,$
                               /NONEXCLUSIVE,$
                               LABEL_LEFT='Output Format:',$
                               UVALUE='Output Format',$
                               SET_VALUE=[1,0])
      
      field = coyote_field2(box3_base,$
                            LABELFONT=buttonfont,$
                            FIELDFONT=textfont,$
                            TITLE='Output File:',$
                            UVALUE='Output File',$
                            XSIZE=25,$
                            EVENT_PRO='xsmoothspec_event',$
                            /CR_ONLY,$
                            TEXTID=textid)
      state.w.outfile_fld = [field,textid]

      
      smooth_button = widget_button(box3_base,$
                                    EVENT_PRO='xsmoothspec_event',$
                                    FONT=buttonfont,$
                                    VALUE='Smooth Spectra',$
                                    UVALUE='Smooth Spectra')

; Get things running.  Center the widget using the Fanning routine.

centertlb,state.w.xsmoothspec_base

widget_control, state.w.xsmoothspec_base, /realize

; Start the Event Loop. This will be a non-blocking program.

XManager, 'xsmoothspec', $
  state.w.xsmoothspec_base, $
  /No_Block,$
  cleanup = 'xsmoothspec_cleanup'

;  Get sizes of things now for resizing

widget_control, state.w.xsmoothspec_base, tlb_get_size = result

; Put state variable into the user value of the top level base.

widget_control, state.w.xsmoothspec_base, set_uvalue=state, /no_copy

end






